'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

require('./select.scss');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _dropdown = require('../dropdown/dropdown.js');

var _dropdown2 = _interopRequireDefault(_dropdown);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } /* eslint-disable react/no-set-state */


/**
 * Select
 * Form controller with custom styles
 */
var Select = function (_Component) {
  _inherits(Select, _Component);

  /**
   * Constructor
   * @param {Object} props - React props
   */
  function Select(props) {
    _classCallCheck(this, Select);

    var _this = _possibleConstructorReturn(this, (Select.__proto__ || Object.getPrototypeOf(Select)).call(this, props));

    _this.state = { value: props.defaultValue };
    _this.handleDropdown = _this.handleDropdown.bind(_this);
    _this.handleBlur = _this.handleBlur.bind(_this);
    _this.handleFocus = _this.handleFocus.bind(_this);
    _this.handleSelect = _this.handleSelect.bind(_this);
    return _this;
  }

  /**
   * Forward checkValidity to the select element
   */


  _createClass(Select, [{
    key: 'checkValidity',
    value: function checkValidity() {
      this._select.checkValidity();
    }

    /**
     * When blurred remove class for focus styles
     */

  }, {
    key: 'handleBlur',
    value: function handleBlur() {
      this.setState({ focus: false });
    }

    /**
     * When focused set class for focus styles
     */

  }, {
    key: 'handleFocus',
    value: function handleFocus() {
      this.setState({ focus: true });
    }

    /**
     * When dropdown change update select value
     * @param {string} value - Selected dropdown value
     */

  }, {
    key: 'handleDropdown',
    value: function handleDropdown(value) {
      // istanbul ignore else
      if (value !== this._select.value) {
        this.setState({ value: value });
        this._select.value = value;
        var event = new window.Event('change', { bubbles: true });
        this._select.dispatchEvent(event);
        if (this.props.onChange) {
          this.props.onChange(event);
        }
      }
    }

    /**
     * When dropdown change update select value
     * @param {object} event - DOM event object
     */

  }, {
    key: 'handleSelect',
    value: function handleSelect(event) {
      this.setState({ value: event.target.value });
      if (this.props.onChange) {
        this.props.onChange(event);
      }
    }

    /**
     * Render method
     * @returns {JSX} - Component template
     */

  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var dropdownOptions = [];

      var _props = this.props,
          className = _props.className,
          onInvalid = _props.onInvalid,
          options = _props.options,
          placeholder = _props.placeholder,
          other = _objectWithoutProperties(_props, ['className', 'onInvalid', 'options', 'placeholder']),
          focus = this.state.focus;

      var selectCSS = (0, _classnames2.default)('selected-option', className, { focus: focus });

      if (placeholder) {
        dropdownOptions = dropdownOptions.concat(options && options[0] && options[0].value ? { value: '', label: placeholder } : placeholder);
      }

      if (options) {
        dropdownOptions = dropdownOptions.concat(options);
      }

      return _react2.default.createElement(
        'div',
        { className: 'select' },
        _react2.default.createElement(
          _dropdown2.default,
          {
            'aria-hidden': 'true',
            onSelect: this.handleDropdown,
            options: dropdownOptions
          },
          _react2.default.createElement(
            'div',
            { className: selectCSS },
            this.state.value || placeholder || '\xA0'
          )
        ),
        _react2.default.createElement(
          'select',
          _extends({}, other, {
            onBlur: this.handleBlur,
            onChange: this.handleSelect,
            onFocus: this.handleFocus,
            onInvalid: onInvalid,
            ref: function ref(_ref) {
              _this2._select = _ref;
            },
            tabIndex: '-1'
          }),
          placeholder && _react2.default.createElement(
            'option',
            { value: '' },
            placeholder
          ),
          options && options.map(function (option, id) {
            return _react2.default.createElement(
              'option',
              { key: id, value: option.value || option },
              option.label || option
            );
          })
        )
      );
    }
  }]);

  return Select;
}(_react.Component);

exports.default = Select;


Select.propTypes = {
  className: _propTypes2.default.string,
  defaultValue: _propTypes2.default.string,
  onChange: _propTypes2.default.func,
  onInvalid: _propTypes2.default.func,
  options: _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.shape({
    value: _propTypes2.default.string,
    label: _propTypes2.default.string
  })])),
  placeholder: _propTypes2.default.string
};