'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Panel;

require('./panel.scss');

var _reactChildrenUtilities = require('react-children-utilities');

var _reactChildrenUtilities2 = _interopRequireDefault(_reactChildrenUtilities);

var _collapsible = require('../collapsible/collapsible.js');

var _collapsible2 = _interopRequireDefault(_collapsible);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Panel
 * @param   {Object} props     - React props
 * @returns    {JSX} template  - Component template
 */
function Panel(props) {
  var children = props.children,
      collapsed = props.collapsed,
      id = props.id,
      title = props.title,
      grouped = _reactChildrenUtilities2.default.groupByType(children, ['header', 'footer'], 'body');

  if (!title && !grouped.header && !grouped.footer) {
    return _react2.default.createElement(
      'div',
      { className: 'panel panel-body' },
      children
    );
  }

  return _react2.default.createElement(
    'div',
    { className: 'panel' },
    (title || grouped.header) && _react2.default.createElement(
      'div',
      {
        'aria-controls': id && id + '-body',
        'aria-expanded': !collapsed,
        className: 'panel-header',
        id: id && id + '-title'
      },
      title || grouped.header
    ),
    _react2.default.createElement(
      _collapsible2.default,
      { collapsed: collapsed },
      _react2.default.createElement(
        'div',
        { className: 'panel-content' },
        _react2.default.createElement(
          'div',
          {
            'aria-labelledby': id && id + '-title',
            className: 'panel-body',
            id: id && id + '-body'
          },
          grouped.body
        ),
        grouped.footer && _react2.default.createElement(
          'div',
          { className: 'panel-footer' },
          grouped.footer
        )
      )
    )
  );
}

Panel.propTypes = {
  children: _propTypes2.default.node,
  collapsed: _propTypes2.default.bool,
  id: _propTypes2.default.string,
  title: _propTypes2.default.string
};